/*------------------------------------------------------------------------------------
   Name: TMS-Osc.mq4
   Copyright 2010, Xaphod, http://forexwhiz.appspot.com
   
   Description: Oscillator for the Trading Made Simple System.
                Similar to TDI RSI Signal Line and Trade Signal Line.
                	          
   Change log: 
       2011-05-16. Xaphod, v1.00 
          - First Release 
-------------------------------------------------------------------------------------*/
// Indicator properties
#property copyright "Copyright  2010, Xaphod"
#property link      "http://forexwhiz.appspot.com"

#property indicator_separate_window
#property indicator_buffers 4
#property indicator_color1 CLR_NONE
#property indicator_width1 1
#property indicator_color2 CLR_NONE
#property indicator_width2 1
#property indicator_color3 Red
#property indicator_width3 2
#property indicator_color4 Green
#property indicator_width4 2
#property indicator_level1 32
#property indicator_level2 50
#property indicator_level3 68
#property indicator_levelstyle STYLE_DOT
#property indicator_levelcolor DimGray

//#include <xDebug.mqh>

// Constant definitions
#define INDICATOR_NAME "TMS-Osc"
#define INDICATOR_VERSION "1.00, 2011, Xaphod"


// Indicator parameters
extern string    Indi.Version= INDICATOR_VERSION;
extern string    RSI.Settings="";
extern int       RSI.Period=13;             // RSI Period
extern int       RSI.Price=PRICE_CLOSE;     // RSI Price Type: CLOSE=0, OPEN=1, HIGH=2, LOW=3, MEDIAN=4, TYPICAL=5, WEIGHTED=6
extern string    RSISignal.Settings="";
extern int       RSISignal.Period=2;        // RSI Signal MA-Filter Period
extern int       RSISignal.Mode=MODE_SMA;   // MA-Filter Method: SMA=0, EMA=1, SMMA=2, LWMA=4
extern string    TradeSignal.Settings="";
extern int       TradeSignal.Period=7;      // Trade Signal MA-Filter Period
extern int       TradeSignal.Mode=MODE_SMA; // MA-Filter Method: SMA=0, EMA=1, SMMA=2, LWMA=4
extern string    MarketBase.Settings="";
extern int       MarketBase.Period=34;      // MarketBase MA-Filter Period
extern int       MarketBase.Mode=MODE_SMA;  // MA-Filter Method: SMA=0, EMA=1, SMMA=2, LWMA=4


// Global module varables
double gadRSI[];
double gadRSISig[];
double gadTradeSig[];
double gadMktBase[];


//-----------------------------------------------------------------------------
// function: init()
// Description: Custom indicator initialization function.
//-----------------------------------------------------------------------------
int init() {
  SetIndexStyle(0, DRAW_LINE);
  SetIndexBuffer(0, gadRSI);
  SetIndexLabel(0,NULL);
  SetIndexStyle(1, DRAW_LINE);
  SetIndexBuffer(1, gadMktBase);
  SetIndexLabel(1,"Market Base");
  SetIndexStyle(2, DRAW_LINE);
  SetIndexBuffer(2, gadTradeSig);
  SetIndexLabel(2,"Trade Signal");
  SetIndexStyle(3, DRAW_LINE);
  SetIndexBuffer(3, gadRSISig);
  SetIndexLabel(3,"RSI Signal");   
  IndicatorDigits(1);
  IndicatorShortName(INDICATOR_NAME);
  return(0);
}

//-----------------------------------------------------------------------------
// function: deinit()
// Description: Custom indicator deinitialization function.
//-----------------------------------------------------------------------------
int deinit() {
   return (0);
}


///-----------------------------------------------------------------------------
// function: start()
// Description: Custom indicator iteration function.
//-----------------------------------------------------------------------------
int start() {
  int iNewBars;
  int iCountedBars; 
  int i;  
  
  // Get unprocessed ticks
  iCountedBars=IndicatorCounted();
  if(iCountedBars < 0) return (-1); 
  if(iCountedBars>0) iCountedBars--;
  iNewBars=Bars-iCountedBars;
  
  // Calc TMS data
  for(i=iNewBars; i>=0; i--) {
    gadRSI[i] = iRSI(NULL,0,RSI.Period,RSI.Price,i); 
  }
  for(i=iNewBars; i>=0; i--) {  
    gadRSISig[i]=iMAOnArray(gadRSI,0,RSISignal.Period,0,RSISignal.Mode,i);
    gadTradeSig[i]=iMAOnArray(gadRSI,0,TradeSignal.Period,0,TradeSignal.Mode,i);    
    gadMktBase[i]=iMAOnArray(gadRSI,0,MarketBase.Period,0,MarketBase.Mode,i);    
  }
  
  return(0);
}
//+------------------------------------------------------------------+


